# Org.OpenAPITools.Api.DefaultApi

All URIs are relative to *https://cognitivecreditapi.com/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**ApiConsumerProjectLocalGetCompanyComparablesSubtypes**](DefaultApi.md#apiconsumerprojectlocalgetcompanycomparablessubtypes) | **GET** /comparables/{interval} | Get company comparables
[**ApiConsumerProjectLocalGetCompanyDatapoint**](DefaultApi.md#apiconsumerprojectlocalgetcompanydatapoint) | **GET** /datapoints/{datapointId} | Get a company datapoint
[**ApiConsumerProjectLocalGetCompanyFinancials**](DefaultApi.md#apiconsumerprojectlocalgetcompanyfinancials) | **GET** /companies/{companyId}/financials | Get company financials
[**ApiConsumerProjectLocalGetCompanyListings**](DefaultApi.md#apiconsumerprojectlocalgetcompanylistings) | **GET** /companies | Get company descriptions
[**ApiConsumerProjectLocalGetCompanyTimeSeries**](DefaultApi.md#apiconsumerprojectlocalgetcompanytimeseries) | **GET** /companies/{companyId}/timeseries/{tag}/{interval} | Get company time series
[**ApiConsumerProjectLocalGetComparablesUpdatesSince**](DefaultApi.md#apiconsumerprojectlocalgetcomparablesupdatessince) | **GET** /comparables/updates | Get company comparables updates for a given time period
[**ApiConsumerProjectLocalGetPeriodDates**](DefaultApi.md#apiconsumerprojectlocalgetperioddates) | **GET** /companies/{companyId}/periods | Get company period dates



## ApiConsumerProjectLocalGetCompanyComparablesSubtypes

> ComparablesResponse ApiConsumerProjectLocalGetCompanyComparablesSubtypes (string interval, DateTime? atTimestamp = null, string companyIds = null, int? limit = null, string continuationToken = null, string acceptEncoding = null)

Get company comparables

Returns comparables data for a list of companies for the allowed coverage_universe

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetCompanyComparablesSubtypesExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var interval = "interval_example";  // string | identifier for the interval of comparables data to fetch
            var atTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return comparables snapshot for (optional) 
            var companyIds = "companyIds_example";  // string | filter by supplied company ids (optional) 
            var limit = 56;  // int? | maximum number of results to return - typically used when paging (optional) 
            var continuationToken = "continuationToken_example";  // string | identifier of last result in previous result set - allows continuation of paged results (optional) 
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company comparables
                ComparablesResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, atTimestamp, companyIds, limit, continuationToken, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyComparablesSubtypes: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **interval** | **string**| identifier for the interval of comparables data to fetch | 
 **atTimestamp** | **DateTime?**| ISO-8601 Timestamp to return comparables snapshot for | [optional] 
 **companyIds** | **string**| filter by supplied company ids | [optional] 
 **limit** | **int?**| maximum number of results to return - typically used when paging | [optional] 
 **continuationToken** | **string**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**ComparablesResponse**](ComparablesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of company-comparables, each with a company id and list of comparable objects. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetCompanyDatapoint

> CompanyDatapointResponse ApiConsumerProjectLocalGetCompanyDatapoint (string datapointId, string acceptEncoding = null)

Get a company datapoint

Returns details of an individual datapoint for a company

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetCompanyDatapointExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var datapointId = "datapointId_example";  // string | identifier for the datapoint
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get a company datapoint
                CompanyDatapointResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyDatapoint(datapointId, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyDatapoint: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **datapointId** | **string**| identifier for the datapoint | 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**CompanyDatapointResponse**](CompanyDatapointResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A single datapoint, including details about its calculation. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetCompanyFinancials

> CompanyFinancialsResponse ApiConsumerProjectLocalGetCompanyFinancials (string companyId, DateTime? atTimestamp = null, string acceptEncoding = null)

Get company financials

Returns historical financials data for single company

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetCompanyFinancialsExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var companyId = "companyId_example";  // string | identifier for the company to fetch financials for
            var atTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return financials snapshot for (optional) 
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company financials
                CompanyFinancialsResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyFinancials(companyId, atTimestamp, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyFinancials: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **string**| identifier for the company to fetch financials for | 
 **atTimestamp** | **DateTime?**| ISO-8601 Timestamp to return financials snapshot for | [optional] 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**CompanyFinancialsResponse**](CompanyFinancialsResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of Financials, each containing a list of historical values. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetCompanyListings

> CompanyDescriptionResponse ApiConsumerProjectLocalGetCompanyListings (DateTime? atTimestamp = null, string isRetired = null, string companyIds = null, string tickers = null, int? limit = null, DateTime? updatedAfter = null, DateTime? updatedBefore = null, DateTime? lastReportedDateAfter = null, DateTime? lastReportedDateBefore = null, string continuationToken = null, string acceptEncoding = null)

Get company descriptions

Returns a list of company description objects.

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetCompanyListingsExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var atTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return companies snapshot for (optional) 
            var isRetired = "isRetired_example";  // string | filter by 'retired' status - (true|false) (optional) 
            var companyIds = "companyIds_example";  // string | filter by supplied company ids - comma separated list (optional) 
            var tickers = "tickers_example";  // string | filter by supplied company tickers (optional) 
            var limit = 56;  // int? | maximum number of results to return - typically used when paging (optional) 
            var updatedAfter = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | Only return company descriptions added or updated on or after this ISO-8601 timestamp (optional) 
            var updatedBefore = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | Only return company descriptions added or updated before this ISO-8601 timestamp (optional) 
            var lastReportedDateAfter = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | Only return company descriptions for companies with reports on or after this ISO-8601 timestamp (optional) 
            var lastReportedDateBefore = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | Only return company descriptions for companies with reports before this ISO-8601 timestamp (optional) 
            var continuationToken = "continuationToken_example";  // string | identifier of last result in previous result set - allows continuation of paged results (optional) 
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company descriptions
                CompanyDescriptionResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyListings(atTimestamp, isRetired, companyIds, tickers, limit, updatedAfter, updatedBefore, lastReportedDateAfter, lastReportedDateBefore, continuationToken, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyListings: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **atTimestamp** | **DateTime?**| ISO-8601 Timestamp to return companies snapshot for | [optional] 
 **isRetired** | **string**| filter by &#39;retired&#39; status - (true|false) | [optional] 
 **companyIds** | **string**| filter by supplied company ids - comma separated list | [optional] 
 **tickers** | **string**| filter by supplied company tickers | [optional] 
 **limit** | **int?**| maximum number of results to return - typically used when paging | [optional] 
 **updatedAfter** | **DateTime?**| Only return company descriptions added or updated on or after this ISO-8601 timestamp | [optional] 
 **updatedBefore** | **DateTime?**| Only return company descriptions added or updated before this ISO-8601 timestamp | [optional] 
 **lastReportedDateAfter** | **DateTime?**| Only return company descriptions for companies with reports on or after this ISO-8601 timestamp | [optional] 
 **lastReportedDateBefore** | **DateTime?**| Only return company descriptions for companies with reports before this ISO-8601 timestamp | [optional] 
 **continuationToken** | **string**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**CompanyDescriptionResponse**](CompanyDescriptionResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of companies, each containing company information |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetCompanyTimeSeries

> CompanyTimeSeriesResponse ApiConsumerProjectLocalGetCompanyTimeSeries (string companyId, string tag, string interval, string acceptEncoding = null)

Get company time series

Returns all historical values of a specific comparable for a given company and interval

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetCompanyTimeSeriesExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var companyId = "companyId_example";  // string | identifier for the company to fetch time series data for
            var tag = "tag_example";  // string | identifier for the comparable tag to fetch time series data for
            var interval = "interval_example";  // string | identifier for the interval to fetch time series data for
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company time series
                CompanyTimeSeriesResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyTimeSeries(companyId, tag, interval, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyTimeSeries: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **string**| identifier for the company to fetch time series data for | 
 **tag** | **string**| identifier for the comparable tag to fetch time series data for | 
 **interval** | **string**| identifier for the interval to fetch time series data for | 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**CompanyTimeSeriesResponse**](CompanyTimeSeriesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of values for a particular comparable, over the reporting history of a particular company for a specific interval. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetComparablesUpdatesSince

> ComparablesResponse ApiConsumerProjectLocalGetComparablesUpdatesSince (DateTime? startTimestamp = null, DateTime? endTimestamp = null, string companyIds = null, int? limit = null, string continuationToken = null, string acceptEncoding = null)

Get company comparables updates for a given time period

Returns comparables data for a list of companies for the allowed coverage_universe, from a given start timestamp and optional end timestamp

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetComparablesUpdatesSinceExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var startTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp) (optional) 
            var endTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp) (optional) 
            var companyIds = "companyIds_example";  // string | filter by supplied company ids (optional) 
            var limit = 56;  // int? | maximum number of results to return - typically used when paging (optional) 
            var continuationToken = "continuationToken_example";  // string | identifier of last result in previous result set - allows continuation of paged results (optional) 
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company comparables updates for a given time period
                ComparablesResponse result = apiInstance.ApiConsumerProjectLocalGetComparablesUpdatesSince(startTimestamp, endTimestamp, companyIds, limit, continuationToken, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetComparablesUpdatesSince: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **startTimestamp** | **DateTime?**| ISO-8601 Timestamp to return comparables updates since (all updates greater than or equal to the timestamp) | [optional] 
 **endTimestamp** | **DateTime?**| ISO-8601 Timestamp to return comparables updates until (all updates less than, but not equal to, the timestamp) | [optional] 
 **companyIds** | **string**| filter by supplied company ids | [optional] 
 **limit** | **int?**| maximum number of results to return - typically used when paging | [optional] 
 **continuationToken** | **string**| identifier of last result in previous result set - allows continuation of paged results | [optional] 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**ComparablesResponse**](ComparablesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of company-comparables, each with a company id and list of comparable objects. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ApiConsumerProjectLocalGetPeriodDates

> CompanyPeriodDatesResponse ApiConsumerProjectLocalGetPeriodDates (string companyId, string acceptEncoding = null)

Get company period dates

Returns end dates of financial reporting periods for given company

### Example

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class ApiConsumerProjectLocalGetPeriodDatesExample
    {
        public static void Main()
        {
            Configuration.Default.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            Configuration.Default.AddApiKey("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.AddApiKeyPrefix("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(Configuration.Default);
            var companyId = "companyId_example";  // string | identifier for the company to fetch financials for
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company period dates
                CompanyPeriodDatesResponse result = apiInstance.ApiConsumerProjectLocalGetPeriodDates(companyId, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetPeriodDates: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }
        }
    }
}
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyId** | **string**| identifier for the company to fetch financials for | 
 **acceptEncoding** | **string**| client supported encodings (gzip, deflate, br) | [optional] [default to &quot;gzip, deflate, br&quot;]

### Return type

[**CompanyPeriodDatesResponse**](CompanyPeriodDatesResponse.md)

### Authorization

[authorizeClient](../README.md#authorizeClient)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | A list of Period Dates, each containing a financial period and its corresponding end date. |  -  |

[[Back to top]](#)
[[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)

